=======
History
=======

0.1.1 (2017-04-23)
------------------

* Add wrapped numpy random functions for easier time function creation.
* Restructure package structure into 'core' and 'functions'.


0.1.0 (2017-04-16)
------------------

* Add TimeSeries and TimeSeriesResult.
* Add TimeTrack and TimeTrackResult.
* Add TimeFunction.
* Add function examples.
